@@ -2,8 +2,8 @@
 ##################################################################
 # Filename: AutoInit_GBase8s.sh
 # Function: Auto install GBase 8s software and auto init database.
-# Write by: liaojinqing@gbase.cn
-# Version : 1.4.1.1   update date: 2022-07-27
+# Write by: liaosnet@gbasedbt.com
+# Version : 1.4.3   update date: 2022-08-12
 ##################################################################
 ##### Defind env
 export LANG=C
@@ -107,7 +107,7 @@ fi
 
 SOFTPACKNAME=$(ls GBase*.tar 2>/dev/null)
 if [ x"$SOFTPACKNAME" = x ]; then
-  loginfo "ERROR: ${ENVCHECK} not found."
+  loginfo "ERROR: GBase Database Soft Package not found."
   exit 2
 fi
 
@@ -255,13 +255,18 @@ export ${USER_UPPER}SQLHOSTS=${INSTALL_DIR}/etc/sqlhosts
 export DB_LOCALE=${GBASELOCALE}
 export CLIENT_LOCALE=${GBASELOCALE}
 export GL_USEGLU=1
+# exprot NODEFDAC=yes
 export DBDATE="Y4MD-"
 export DBACCESS_SHOW_TIME=1
 EOF
 
 # sqlhosts
 loginfo "Building ${INSTALL_DIR}/etc/sqlhosts ."
-echo "$GBASESERVER onsoctcp 0.0.0.0 ${PORTNO:-9088}" > $INSTALL_DIR/etc/sqlhosts
+# echo "$GBASESERVER onsoctcp 0.0.0.0 ${PORTNO:-9088}" > $INSTALL_DIR/etc/sqlhosts
+cat > $INSTALL_DIR/etc/sqlhosts <<EOF 2>/dev/null
+${GBASESERVER}     onsoctcp 0.0.0.0 ${PORTNO:-9088}
+${GBASESERVER}_shm onipcshm 0.0.0.0 ${PORTNO:-9099}
+EOF
 chown ${USER_NAME}:${USER_NAME} $INSTALL_DIR/etc/sqlhosts
 chmod 0644 $INSTALL_DIR/etc/sqlhosts
 
@@ -275,6 +280,7 @@ loginfo "Building $CFGFILE ."
 sed -i "s#^ROOTPATH.*#ROOTPATH $DATADIR/rootchk#g" $CFGFILE
 sed -i "s#^ROOTSIZE.*#ROOTSIZE $ROOTSIZE#g" $CFGFILE
 sed -i "s#^DBSERVERNAME.*#DBSERVERNAME $GBASESERVER#g" $CFGFILE
+sed -i "s#^DBSERVERALIASES.*#DBSERVERALIASES ${GBASESERVER}_shm#g" $CFGFILE
 sed -i "s#^TAPEDEV.*#TAPEDEV /dev/null#g" $CFGFILE
 sed -i "s#^LTAPEDEV.*#LTAPEDEV /dev/null#g" $CFGFILE
 sed -i "s#^USERMAPPING.*#USERMAPPING ADMIN#g" $CFGFILE
@@ -453,6 +459,7 @@ sed -i "s#^SBSPACENAME.*#SBSPACENAME sbspace01#g" $CFGFILE
 sed -i "s#^SYSSBSPACENAME.*#SYSSBSPACENAME sbspace01#g" $CFGFILE
 sed -i "s#^MULTIPROCESSOR.*#MULTIPROCESSOR 1#g" $CFGFILE
 sed -i "s#^AUTO_TUNE.*#AUTO_TUNE 0#g" $CFGFILE
+sed -i "/^AUTO_TUNE/a\AUTO_REPREPARE 1" $CFGFILE
 sed -i "s#^CLEANERS.*#CLEANERS 32#g" $CFGFILE
 sed -i "s#^STACKSIZE.*#STACKSIZE 512#g" $CFGFILE
 sed -i "s#^ALLOW_NEWLINE.*#ALLOW_NEWLINE 1#g" $CFGFILE
