@@ -2,8 +2,8 @@
 ##################################################################
 # Filename: CleanAll.sh
 # Function: Clean GBase 8s Auto Install.
-# Write by: liaojinqing@gbase.cn
-# Version : 1.4.0   update date: 2022-01-11
+# Write by: liaosnet@gbasedbt.com
+# Version : 1.4.3   update date: 2022-08-12
 ##################################################################
 ##### Define Parameter
 ##### Get Parameter
@@ -39,9 +39,9 @@ fi
 
 INSTALL_DIR=$(su - ${USER_NAME} -c "env | grep GBASEDBTDIR")
 INSTALL_DIR=${INSTALL_DIR#*=}
-su - ${USER_NAME} -c "onmode -ky"
-su - ${USER_NAME} -c "onclean -ky"
-ps -ef | awk '/oninit/ && $3==1{print "kill -9 "$2}' | sh
+su - ${USER_NAME} -c "onmode -ky" 2>/dev/null
+su - ${USER_NAME} -c "onclean -ky" 2>/dev/null
+ps -ef | awk '/oninit/ && $3==1{print "kill -9 "$2}' | sh 2>/dev/null
 userdel -rf ${USER_NAME} 2>/dev/null
 groupdel ${USER_NAME} 2>/dev/null
 
